@@ -1,4 +1,3 @@
-#!/usr/bin/env python
 # coding: utf-8
 
 # Copyright (c) Jupyter Development Team.
@@ -56,7 +55,7 @@ else:
         return ' '.join(map(pipes.quote, cmd_list))
 
 
-__version__ = '0.10.2'
+__version__ = '0.10.3'
 
 # ---------------------------------------------------------------------------
 # Top Level Variables
@@ -459,6 +458,8 @@ def command_for_func(func):
 def ensure_python(specs):
     """Given a list of range specifiers for python, ensure compatibility.
     """
+    if sys.version_info >= (3, 10):
+        raise RuntimeError("ensure_python is deprecated and not compatible with Python 3.10+")
     if not isinstance(specs, (list, tuple)):
         specs = [specs]
     v = sys.version_info
